@@ -6,16 +6,29 @@ using a Metropolis-Hastings Monte Carlo algorithm
 -------------------------------------------------------
 	AIC model test   R O U T I N E S
 
-	Peter Beerli 2001, Seattle
-	beerli@fsu.edu
 
-	Copyright 2001-2002 Peter Beerli and Joseph Felsenstein
+Copyright 1997-2002 Peter Beerli and Joseph Felsenstein 
+Copyright 2003-2008 Peter Beerli
+Copyright 2009-2012 Peter Beerli and Michal Palczewski
 
-	This software is distributed free of charge for non-commercial use
-	and is copyrighted. Of course, we do not guarantee that the software
-	works and are not responsible for any damage you may cause or have.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
 
-$Id: aic.c 1702 2010-06-14 14:18:13Z beerli $ 
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+$Id: aic.c 2067 2012-07-27 20:59:32Z beerli $ 
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -144,11 +157,11 @@ void aic_score_driver(aic_struct *aic, MYREAL mle, MYREAL mleaic, nr_fmt *nr, wo
     memcpy (aic->aicvec[0].pattern, world->options->custm2, sizeof (char) * nr->partsize);
     if (world->options->fast_aic)
     {
-        fast_aic_score (&aic->aicvec, &aic->aicnum, nr, 0, world->numpop,
+        fast_aic_score (&aic->aicvec, &aic->aicnum, nr, 0L, world->numpop,
                         temppattern, aic->param0, world->options->aictype[0]);
         memcpy (world->options->custm2, savecustm, sizeof (char) * nr->numpop2);
         if(world->options->aictype[1]!='\0')
-            fast_aic_score (&aic->aicvec, &aic->aicnum, nr, 0, world->numpop,
+            fast_aic_score (&aic->aicvec, &aic->aicnum, nr, 0L, world->numpop,
                             temppattern, aic->param0, world->options->aictype[1]);
     }
     else
@@ -156,13 +169,13 @@ void aic_score_driver(aic_struct *aic, MYREAL mle, MYREAL mleaic, nr_fmt *nr, wo
         //find aic scores in a branch-and-bound fashion
         // with some parameters set to zero, this needs more
         // investigation because of boundary problems
-        aic_score (&aic->aicvec, &aic->aicnum, nr, 0, world->numpop,
+        aic_score (&aic->aicvec, &aic->aicnum, nr, 0L, world->numpop,
                    temppattern, aic->param0, world->options->aictype[0]);
         memcpy (world->options->custm2, savecustm, sizeof (char) * nr->numpop2);
         // aic scores based on averaging M (not 4Nm)
         if(world->options->aictype[1]!='\0')
         {
-            aic_score (&aic->aicvec, &aic->aicnum, nr, 0, world->numpop, temppattern,
+            aic_score (&aic->aicvec, &aic->aicnum, nr, 0L, world->numpop, temppattern,
                        aic->param0, world->options->aictype[1]);
             memcpy (world->options->custm2, savecustm, sizeof (char) * nr->numpop2);
         }
@@ -258,7 +271,7 @@ akaike_information (world_fmt * world, long *Gmax)
     }
     nr = (nr_fmt *) mycalloc (1, sizeof (nr_fmt));
 	
-    create_nr (nr, world, *Gmax, 0, world->loci, world->repkind, world->rep);
+    create_nr (nr, world, *Gmax, 0L, world->loci, world->repkind, world->rep);
 	
     SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
                  world->loci, kind, multilocus);
@@ -654,8 +667,8 @@ long find_paramnum(world_fmt *world, char *connect)
 			}
             temp2 = strtok(NULL," ;,:\n\t\r");
 		}
-        cc = scan_connect (temp, 0, world->numpop2, 'c');
-        tm = scan_connect (temp, 0, world->numpop, 'm');
+        cc = scan_connect (temp, 0L, world->numpop2, 'c');
+        tm = scan_connect (temp, 0L, world->numpop, 'm');
         mm = scan_connect (temp, world->numpop, world->numpop2, 'm');
 	//        mmm = scan_connect (temp, world->numpop, world->numpop2, 'M');
         ms = scan_connect (temp, world->numpop, world->numpop2, 's')/2;
