@@ -33,12 +33,12 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 
-$Id: definitions.h 2105 2012-11-28 16:21:38Z beerli $
+$Id: definitions.h 2138 2013-02-27 01:30:39Z beerli $
  
 *----------------------------------------------------------------
 */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.4.1"
+#define MIGRATEVERSION "3.5.0"
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
@@ -90,7 +90,7 @@ $Id: definitions.h 2105 2012-11-28 16:21:38Z beerli $
 #endif
 
 #include "conf.h"
-#undef HAVE_LGAMMA
+//#undef HAVE_LGAMMA
 #define HAVE_STRFTIME 1
 //#define HIGHBITS
 // #define LAMARC_MALLOC
@@ -615,6 +615,9 @@ long chains is used */
 #ifdef __WIN32__
 #define MYSYSTEM "Windows"
 #endif
+#ifdef __CYGWIN__
+#define MYSYSTEM "Windows(cygwin)"
+#endif
 #ifndef MYSYSTEM
 #define MYSYSTEM "Other"
 #endif
