@@ -33,6 +33,7 @@ OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <errno.h>
 extern int myID;
 extern int numcpu;
+extern MYREAL scaling_prior(world_fmt *world, long numparam, MYREAL val);
 #ifdef ZNZ
 void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options, char **files, long fnum);
 #else
@@ -192,6 +193,8 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   boolean *done;
   boolean recordedusem = options->usem;
   MYREAL *oldmeans;
+  MYREAL theta;
+  boolean notusem = !world->options->usem;
 #ifndef ZNZ
   FILE *mdimfile = fmdimfile;
 #else
@@ -199,7 +202,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 #endif
   long f;
   done = (boolean *) mycalloc(world->loci, sizeof(boolean));
-  params = (MYREAL *) mycalloc(2+ numpop2 + world->bayes->mu, sizeof(MYREAL));
+  params = (MYREAL *) mycalloc(2 + numpop2 + world->bayes->mu, sizeof(MYREAL));
   oldmeans = (MYREAL *) mycalloc(2+ numpop2 + world->bayes->mu, sizeof(MYREAL));
   autocorrelation = (MYREAL *) mycalloc(2 * world->loci * nn, sizeof(MYREAL));
   ess = autocorrelation + world->loci * nn;
@@ -288,14 +291,18 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 		  done[locus] = TRUE;
 		  // allocate the number of bins for the histogram
 		  bayes->histogram[locus].binsum = get_fullbinsum(lowerbound, upperbound, world, options, locus);
-		  bayes->histogram[locus].results = (MYREAL *) mycalloc(bayes->histogram[locus].binsum + 1, sizeof(MYREAL));
+		  bayes->histogram[locus].results = (float *) mycalloc(bayes->histogram[locus].binsum + 1, sizeof(float));
 		  bayes->histogram[locus].set95 = (char *) mycalloc(bayes->histogram[locus].binsum* 2 + 2, sizeof(char));
 		  bayes->histogram[locus].set50 = world->bayes->histogram[locus].set95 + bayes->histogram[locus].binsum + 1;
-		  memset(world->bayes->histogram[locus].results, 0 , sizeof(MYREAL) * (world->bayes->histogram[locus].binsum)); 
+		  //memset(world->bayes->histogram[locus].results, 0 , sizeof(float) * (world->bayes->histogram[locus].binsum)); 
 		  if(bayes->histogram[locus].covariance==NULL)
 		    doublevec2d(&bayes->histogram[locus].covariance,world->numpop2, world->numpop2);
 		}
 	      hist = &bayes->histogram[locus];
+	      //for (j0=0;j0<numpop2;j0++)
+	      //{
+	      //  hist->results[(j0+1)*hist->bins[j0]-1]=-99999.0;
+	      //}
 	      numbinsall = 0;
 	      for(j0=0;j0 < numpop2; j0++)
 		{
@@ -306,6 +313,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 		  else
 		    {
 		      params[j+2] =  atof(strsep(&inptr,"\t"));
+		      /* 2/11/13
 		      if(j>=numpop && options->usem!=recordedusem)
 			{
 			  m2mm(j, numpop,&frompop,&topop);
@@ -317,18 +325,33 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 			    {
 			      params[j+2] /= params[topop+2];
 			    }
-			}
+			    }*/
 		      n[j] += 1;
 		      oldmeans[j] = hist->means[j];
 		      hist->means[j] += (params[j+2] - hist->means[j]) / n[j];
 		    }
 		  numbinsall += hist->bins[j];
 		  numbins = numbinsall - hist->bins[j];
+		  
+		  //if((notusem) && (j>=world->numpop))
+		  //  {
+		  //    m2mm(j,world->numpop,&frompop, &topop);
+		  //    theta = params[topop+2];
+		  //    bin = (long) (theta*(params[j+2]-lowerbound[j]) / delta[j]);
+		  //  }
+		  //else
+		  if (params[j+2]>upperbound[j])
+		    {
+		      warning("above upper bound: %f\n",params[j+2]);
+		      continue;
+		    }
 		  bin = (long) ((params[j+2]-lowerbound[j]) / delta[j]);
+		  //		  printf("%li: %f %f %f\n",j, params[j+2],hist->results[numbins + bin],scaling_prior(world,j,params[j+2]));
 		  hist->minima[j0] = lowerbound[j];
 		  hist->maxima[j0] = upperbound[j];
 		  hist->results[numbins + bin] += 1.;
 		  bayes->histtotal[locus * np + j] += 1;
+
 		}
 	      if(bayes->mu)
 		{
