@@ -5,6 +5,7 @@
 //
 #include "migration.h"
 #include "sighandler.h"
+#include "watterson.h"
 
 ///
 /// returns the number of states for a specific mutation model
@@ -188,3 +189,43 @@ void finish_mutationmodel(world_fmt *world, data_fmt *data, option_fmt *options)
 	  z++;
     }
 }
+
+void print_mutationrate_weights(FILE *file, MYREAL *murates, long *segregs, MYREAL *wattersons, long loci)
+{
+  long locus;
+  char ***buffer;
+  long rows = loci+2;
+  float mumean=0.0;
+  float segregmean=0.0;
+  float wamean=0.0;
+  fprintf(file,"Relative mutation rate among loci estimated from the data \n");
+  fprintf(file,"==========================================================\n");
+  if(wattersons==NULL)
+    {
+      fprintf(file,"Locus       Relative        Number of alleles\n");
+      fprintf(file,"            mutation rate    \n");
+      fprintf(file,"--------    -------------   -----------------\n");
+      for (locus=0; locus < loci; locus++)
+	{
+	  fprintf(file,"%5li          % 5.5f         % 6li\n",locus+1, murates[locus], segregs[locus]);
+	  mumean += (murates[locus] - mumean)/(locus+1);
+	  segregmean += (segregs[locus] - segregmean)/(locus+1);
+	}
+      fprintf(file,"%5s          % 5.5f         % 6.1f\n","All", mumean, segregmean);
+    }
+  else
+    {
+      fprintf(file,"Locus       Relative        Watterson's Theta  Segregating\n");
+      fprintf(file,"            mutation rate   (per site)         sites      \n");
+      fprintf(file,"--------    -------------   -----------------  -----------\n");
+      for (locus=0; locus < loci; locus++)
+	{
+	  fprintf(file,"%5li          % 5.5f         %2.8f      % 6li\n",locus+1, murates[locus], wattersons[locus], segregs[locus]);	
+	  mumean += (murates[locus] - mumean)/(locus+1);
+	  wamean += (wattersons[locus] - wamean)/(locus+1);
+	  segregmean += (segregs[locus] - segregmean)/(locus+1);
+	}
+      fprintf(file,"%5s          % 5.5f         %2.8f      % 6.1f\n","All", mumean, wamean, segregmean);	
+      fprintf(file,"\n\n\n");
+    }
+}
