@@ -16,7 +16,7 @@ Copyright 2003-2012 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 2095 2012-10-25 21:40:10Z beerli $
+$Id: reporter.c 2127 2013-01-30 10:13:45Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -317,6 +317,31 @@ calc_allgelmanb (MYREAL *gelmanb, MYREAL *mc, MYREAL *chainmeans, long *nmeans,
 }
 
 
+///
+/// collect the autocorrelation values and the ESS values
+void collect_acceptance(world_fmt *world)
+{
+  const long np = world->numpop2;
+  const long nn = world->numpop2 + world->bayes->mu; //position of genealogy acceptance
+  // the archives have length of #parameters + #all_loci_murates + genealogy
+  long i;
+  for(i=0;i<np; i++)
+    {
+      world->accept_archive[i] += world->bayes->accept[i];
+      world->trials_archive[i] += world->bayes->trials[i];
+    }
+  if(world->bayes->mu)
+    {
+      i = world->locus + np;
+      world->accept_archive[i] += world->bayes->accept[np];
+      world->trials_archive[i] += world->bayes->trials[np];
+    }
+  world->accept_archive[nn] += world->bayes->accept[nn];
+  world->trials_archive[nn] += world->bayes->trials[nn];
+  
+  
+}
+
 ///
 /// collect the autocorrelation values and the ESS values
 void collect_ess_values(world_fmt *world)
@@ -335,7 +360,7 @@ void collect_ess_values(world_fmt *world)
       world->ess_archive[i] += world->effective_sample[i];
     }
   n++;
-  printf("%i> %li autoarchive %f autocorr %f n=%li\n", myID, world->rep,  world->auto_archive[0], world->autocorrelation[0], nn);
+  //printf("%i> %li autoarchive %f autocorr %f n=%li\n", myID, world->rep,  world->auto_archive[0], world->autocorrelation[0], nn);
 }
 
 
@@ -1182,6 +1207,9 @@ chain_means (MYREAL *thischainmeans, world_fmt * world)
     }
   else
     {
+#ifdef DEBUG
+      printf("%i> world->rep=%li\n",myID, world->rep);
+#endif
       world->convergence->chain_counts[world->rep] = world->atl[world->rep][world->locus].T;
       chain_means_ml (thischainmeans, world);
     }
