@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1892 2011-05-26 17:00:58Z beerli $
+ $Id: sequence.c 2120 2013-01-03 05:17:21Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -97,8 +97,10 @@ init_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
 {
 
     long sites = world->data->seq[0]->sites[locus];
-    if (world->options->datatype == 'u')
+    if (options->datatype == 'u')
         sites *= 5;
+    if (options->datatype == 'n')
+        sites += 4;
     if (!world->data->seq[0]->done || world->data->seq[0]->alias == NULL)
     {
         world->data->seq[0]->done = TRUE;
@@ -1140,7 +1142,7 @@ sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long site
     
     for (i = 0; i < data->numpop; i++)
     {
-      numind = ((options->randomsubset > 0) && (options->randomsubset < data->numind[0][locus])) ? options->randomsubset : data->numind[i][locus];
+      numind = ((options->randomsubset > 0) && (options->randomsubset < data->numind[i][locus])) ? options->randomsubset : data->numind[i][locus];
       if (numind > 0)
         {
 	  temppop[z] = i;
@@ -1739,6 +1741,7 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
     //    printf("invariant0=%f\n",invariants[0]);
 }    /* snp_invariants*/
 
+
 MYREAL
 treelike_snp (world_fmt * world, long locus)
 {
@@ -1937,7 +1940,8 @@ copy_seq (world_fmt * original, world_fmt * kopie)
     kseq->addon = oseq->addon;
 }
 
-void find_rates_fromdata(data_fmt * data, option_fmt * options)
+
+void find_rates_fromdata(data_fmt * data, option_fmt * options, world_fmt *world)
 {
   long locus;
   long pop;
@@ -1957,8 +1961,9 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
   MYREAL mean=0.;
   MYREAL delta = 0.;
 
-  numind = (long *) mycalloc (data->loci, sizeof (long));
-
+  numind  = (long *) mycalloc (data->loci, sizeof (long));
+  options->segregs = (long *) mycalloc (data->loci, sizeof (long));
+  options->wattersons = (MYREAL *) mycalloc (data->loci, sizeof (MYREAL));
   for (locus=0; locus < loci; locus++)
     {
       maxsites = (data->seq[0]->sites[locus] > maxsites ? data->seq[0]->sites[locus] : maxsites);
@@ -2007,8 +2012,6 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
   n = 0;
   mean = 0. ;
   options->muloci = loci;
-  fprintf(stdout,"Relative mutation rate among loci estimated from the data\n");
-  fprintf(stdout,"---------------------------------------------------------\n");
   for (locus=0; locus < loci; locus++)
     {
       segreg = 0;
@@ -2016,12 +2019,41 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
 	{
 	  segreg += (long) (v[locus][sites] > 0); 
 	}
-      // originally U use just the plain watterson estimates but
+      options->segregs[locus] = segreg;
+      if(segreg==0)
+	{
+	  if (options->onlyvariable)
+	    {
+	      data->skiploci[locus] = TRUE;
+	      data->locusweight[locus] = 0.0;
+	    }
+	  else
+	    {
+	      if (options->has_variableandone)
+		{
+		  if (options->firstinvariant == -1)
+		    {
+		      options->firstinvariant=locus;
+		      data->locusweight[locus] = 1.0;
+		    }
+		  else
+		    {
+		      data->skiploci[locus] = TRUE;
+		      data->locusweight[locus] = 0.0;
+		      data->locusweight[options->firstinvariant] +=1;
+		    }
+		}
+	    }
+	}
+      // originally I used just the plain watterson estimates but
       // this leads to strange results with highly unequal sequences
       // now the watterson's theta is adjusted per site
       // and that is used to generate the relative rate from the data
       // PB April 3 2011
-      options->mu_rates[locus] = (watterson(segreg,numind[locus]) + 0.0000001)/data->seq[0]->sites[locus];
+      options->wattersons[locus] = watterson(segreg,numind[locus]);
+      options->mu_rates[locus] = (options->wattersons[locus] + 0.0000001)/data->seq[0]->sites[locus];
+      if (data->seq[0]->sites[locus]>0)
+	options->wattersons[locus] /= data->seq[0]->sites[locus];
       n = n + 1;
       delta = options->mu_rates[locus] - mean;
       mean += delta/n;
@@ -2031,10 +2063,6 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
       for (locus=0; locus < loci; locus++)
 	{
 	  options->mu_rates[locus] /= mean;
-	  if(options->progress)
-	    {
-	      fprintf(stdout,"Locus %2li: rate=%f (Watterson's overall Theta = %f)\n",locus+1, options->mu_rates[locus],options->mu_rates[locus] * mean);
-	    }
 	}
     }
   else
@@ -2043,12 +2071,21 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
       options->murates_fromdata = FALSE;
       warning("Relative mutation rates estimation from data was requested but attempt failed --> reset to all-equal rates");
     }
-  fprintf(stdout,"\n\n\n");
   myfree(v[0]);
   myfree(v);
   myfree(numind);
 }
 
+void find_rates_fromdata_alleles(data_fmt * data, option_fmt * options, world_fmt *world, MYREAL mean)
+{
+  long locus;
+  options->segregs = (long *) mycalloc(data->loci, sizeof(long));
+  for (locus=0;locus < data->loci; locus++)
+    {
+      options->segregs[locus] = lround(options->mu_rates[locus] *  mean);
+    }
+}
+
 
 void free_seq(seqmodel_fmt **seq, long seqnum)
 {
