@@ -24,13 +24,13 @@
 #include <stdarg.h>
 #include <signal.h>
 #include "definitions.h"
-#define ON 1
-#define OFF 0
+#define ON 1L
+#define OFF 0L
 extern void signalhandling (long switcher);
 extern void signalhandler (int sig);
 extern void warning (char string[], ...);
 extern void usererror (char string[], ...);
-#define error(x) sig_error(x, __FILE__,__LINE__)
+#define error(x) sig_error(x, __FILE__,(long) __LINE__)
 extern void sig_error (char string[], char filename[], long line);
 
 extern char myfgets (char *buffer, long bufsize, FILE * infile);
@@ -58,9 +58,9 @@ extern void *LAMARC_calloc (size_t repeats,
                                 const long line);
 extern void *LAMARC_realloc (void *ptr, size_t,
                                  const char file[], const long line);
-#define mymalloc(a) LAMARC_malloc((size_t) a,__FILE__,__LINE__)
-#define mycalloc(b,a) LAMARC_calloc((size_t) b, (size_t) a,__FILE__,__LINE__)
-#define myrealloc(c,a) LAMARC_realloc(c, (size_t) a,__FILE__,__LINE__)
+#define mymalloc(a) LAMARC_malloc((size_t) a,__FILE__,(const long)__LINE__)
+#define mycalloc(b,a) LAMARC_calloc((size_t) b, (size_t) a,__FILE__,(const long)__LINE__)
+#define myrealloc(c,a) LAMARC_realloc(c, (size_t) a,__FILE__,(const long) __LINE__)
 #else
 #define mymalloc(a) malloc((size_t) a)
 #define mycalloc(b,a) calloc((size_t) b, (size_t) a)
