@@ -53,14 +53,13 @@ MYREAL waiting_theta(long pop,
   long i;
   long kpop;
   MYREAL expected = 0.0;
-  
   for(i=0;i<numpop; i++)
     {
       if(lineages[i]>0)
-	expected += (lineages[i] * (lineages[i]-1) * (1.0/ param[i]) +  mig0list[i] * lineages[i]) ;
+	expected += (lineages[i] * (lineages[i]-1) * (1.0/ (param[i])) +  mig0list[i] * lineages[i]) ;
     }
   kpop = lineages[pop] * ( lineages[pop] -1);
-  expected = 1./interval - (expected - kpop * 1.0 / param[pop])*inv_mu_rate;
+  expected = 1./interval - (expected - kpop * 1.0 / (param[pop]))*inv_mu_rate;
   // 
   if(expected > EPSILON)
     return kpop / expected;
@@ -86,7 +85,7 @@ MYREAL waiting_M(long pop,long to,
     {
       line = lineages[i];
       if(line>0)
-	expected += (lineages[i] * (lineages[i]-1) * (1.0/ param[i]) +  mig0list[i] * lineages[i]);
+	expected += (lineages[i] * (lineages[i]-1) * (1.0/ (param[i])) +  mig0list[i] * lineages[i]);
     }
   kpop = lineages[to];
   expected = 1./interval - (expected - kpop * param[pop]) * inv_mu_rate ;
